@@ -1,4 +1,3 @@
-import asyncio
 import base64
 import logging
 import random
@@ -82,8 +81,6 @@ def encode(payload):
 
 async def raise_for_status(resp):
     if resp.status >= 400:
-        loop = asyncio.get_event_loop()
-
         try:
             log.error(await resp.json())
         except aiohttp.client_exceptions.ContentTypeError:
@@ -105,6 +102,6 @@ async def retry(coro, exceptions=None, retries=3):
                 raise
             if attempt >= retries - 1:
                 raise
-            log.warning('retrying due to %s', e)
+            log.warning('retrying due to %s', str(e))
 
     raise Exception('hit retry limit ({})'.format(retries))
